@@ -1,7 +1,7 @@
 #!/usr/bin/env bash
 ## Script for creating a UEFI CD bootable ISO from existing Archboot ISO
 ## by Tobias Powalowski <tpowa@archlinux.org>
-## Contributed by "Keshav Padram" <the ddoott ridikulus ddoott rat aatt geemmayil ddoott ccoomm>
+## Contributed by "Keshav Padram Amburay" <the ddoott ridikulus ddoott rat aatt geemmayil ddoott ccoomm>
 # change to english locale!
 export LANG="en_US"
 
@@ -92,6 +92,7 @@ xorriso -as mkisofs \
         -eltorito-alt-boot -e CDEFI/cdefiboot.img -isohybrid-gpt-basdat \
         -no-emul-boot \
         -isohybrid-mbr "${ISOIMG}"/boot/syslinux/isohdpfx.bin \
+        --sort-weight 1 boot/syslinux/isolinux.bin \
         -output "${OUTPUT_IMAGENAME}" "${ISOIMG}"/ &> /tmp/xorriso.log
 
 if [[ -e "${OUTPUT_IMAGENAME}" ]]; then
